<h1 align="center">
  <br>
  <a href="https://pypi.org/project/mgt2001/"><img src="mgt2001-logo.png" alt="mgt2001" width="200"></a>
  <br>
  mgt2001 - THE Package for 2020 Fall MGT 2001 @ NTU
  <br>
</h1>

<h4 align="center">A small package for MGT 2001 use only.</h4>

<p align="center">
  <a href="https://gitter.im/icheft/MGT2001">
    <img src="https://badges.gitter.im/icheft/MGT2001.svg"
         alt="Join the chat at https://gitter.im/icheft/MGT2001">
  </a>
</p>

<p align="center">
  <a href="#demo">Intro</a> •
  <a href="#getting-started">Getting Started</a> •
  <a href="#how-to-use">Usage</a> •
  <a href="#contribution">Contribution</a> •
  <a href="#credits">Credits</a>
</p>

## Intro
The goal for this python package is to provide NTUIM students with an easier solution for everything. This can be labelling issues in bar charts, generating a set of colors, and many more. Throughout the course, we hope to fill this package with useful and handy functions that can be used in the assignments, quizzes, and probably even for the future projects. 

## Getting Started
### Terminal
Should be able to install the package via PyPI:
```sh
pip install mgt2001
```

If you have already installed and are considering an update:
```sh
pip install mgt2001 --upgrade
```

### `.ipynb` Files
If you are on Windows, this method probably serves you better. Just copy the above code onto any of the code blocks.

Should be exactly the same, but instead of copying and pasting the whole text, add a `!` at the beginning of the line.

It is installable via:
```sh
!pip install mgt2001
```

or 

```sh
!pip install mgt2001 -- upgrade
```

Which again depends on your needs.
